/*
 * Copyright (c) 2009, Mason Green (zzzzrrr)
 * http://www.dsource.org/projects/openmelee
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * * Neither the name of the polygonal nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
module openmelee.ships.planet;

import blaze.dynamics.bzBody : bzBody;
import blaze.bzWorld: bzWorld;
import blaze.dynamics.bzBodyDef;
import blaze.collision.shapes.bzCircle : bzCircleDef;
import blaze.common.bzMath: bzVec2;

import openmelee.ships.ship: Ship, State;


class Planet : Ship
{
    this(bzWorld world) {
        super(world);
        init();
        calcRadius();
    }
    
    void init() {
        // Create planet
        bzVec2 position = bzVec2.zeroVect;
        float angle = 0.0f;
        auto bd = new bzBodyDef(position, angle);
        rBody = world.createBody(bd);
        float radius = 7.0f;
        float density = 7.5f;
        auto sd = new bzCircleDef(density, radius);
        float friction = 1.0f;
        float restitution = 0.1f;
        sd.friction = friction;
        sd.restitution = restitution;
        rBody.createShape(sd);   
    }    
}
